Discover Packages
github.com/ge-editor/locale
package
module
Version:
v0.1.1
Opens a new window with list of versions in this module.
Published: May 26, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type BreakPolicy interface {
IsBreakPoint(p2, p1, c rune ) bool
}
type BreakRule func(p2, p1, c rune ) bool
type Bullet struct {
Marker []byte
Width int
}
Cell represents a single character Cell on screen.
const (
OTHER CharClass = 1 << iota
CONTROLCODE
TAB
NEWLINE
DEL
EOF
WORD
NUMBER
ALPHABET
PROHIBITED
DECIMAL_SEPARATOR
WIDECHAR
UPPERCASE
SYMBOL
SPACE
HIRAGANA
KATAKANA
)
type WordPolicy interface {
Boundary(text []byte , cursor int ) (start, end int , ok bool )
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.